@@ -1817,9 +1817,12 @@ autoar_extractor_step_decide_destination (AutoarExtractor *self)
     autoar_extractor_signal_decide_destination (self,
                                                 self->prefix,
                                                 files,
-                                                &new_destination);
+                                                &self->new_prefix);
 
-    self->new_prefix = new_destination;
+    if (self->new_prefix && g_file_equal (self->prefix, self->new_prefix)) {
+      /* This prevents redundant path name handling later. */
+      g_clear_object (&self->new_prefix);
+    }
   } else {
     autoar_extractor_signal_decide_destination (self,
                                                 self->destination_dir,
@@ -1832,28 +1835,11 @@ autoar_extractor_step_decide_destination (AutoarExtractor *self)
     }
   }
 
-  new_destination = (self->new_prefix != NULL) ? self->new_prefix : self->destination_dir;
-  destination_name = g_file_get_path (new_destination);
+  destination_name = g_file_get_path (self->new_prefix != NULL ?
+                                      self->new_prefix :
+                                      self->destination_dir);
   g_debug ("autoar_extractor_step_decide_destination: destination %s", destination_name);
 
-  g_file_make_directory_with_parents (new_destination,
-                                      self->cancellable,
-                                      &(self->error));
-
-  if (g_error_matches (self->error, G_IO_ERROR, G_IO_ERROR_EXISTS)) {
-    GFileType file_type;
-
-    file_type = g_file_query_file_type (new_destination,
-                                        G_FILE_QUERY_INFO_NONE,
-                                        NULL);
-
-    if (file_type == G_FILE_TYPE_DIRECTORY) {
-      /* FIXME: Implement a way to solve directory conflicts */
-      g_debug ("autoar_extractor_step_decide_destination: destination directory exists");
-      g_clear_error (&self->error);
-    }
-  }
-
   g_list_free_full (files, g_object_unref);
 }
 
@@ -1911,6 +1897,8 @@ autoar_extractor_step_extract (AutoarExtractor *self) {
     while (file_conflict) {
       GFile *new_extracted_filename = NULL;
 
+      g_debug ("autoar_extractor_step_extract: conflict detected");
+
       /* Do not try to solve any conflicts in parents for now. Especially
        * symlinks in parents are dangerous as it can easily happen that files
        * are written outside of the destination. The tar cmd fails to extract
